[![Build Status](https://github.com/hukkinj1/mdformat-web/workflows/Tests/badge.svg?branch=master)](<https://github.com/hukkinj1/mdformat-web/actions?query=workflow%3ATests+branch%3Amaster+event%3Apush>)
[![PyPI version](<https://img.shields.io/pypi/v/mdformat-web>)](<https://pypi.org/project/mdformat-web>)

# mdformat-web
> Mdformat plugin to format JS and CSS code blocks

## Description
mdformat-web is an [mdformat](https://github.com/executablebooks/mdformat) plugin
that makes mdformat format JavaScript and CSS code blocks with [JS Beautifier](https://github.com/beautify-web/js-beautify).

## Installing
```bash
pip install mdformat-web
```

## Usage
```bash
mdformat YOUR_MARKDOWN_FILE.md
```
